=========
Thingy:52
=========


.. image:: https://img.shields.io/pypi/v/thingy52.svg
        :target: https://pypi.python.org/pypi/thingy52

.. image:: https://img.shields.io/travis/SebastianRoll/thingy52.svg
        :target: https://travis-ci.org/SebastianRoll/thingy52

.. image:: https://readthedocs.org/projects/thingy52/badge/?version=latest
        :target: https://thingy52.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/SebastianRoll/thingy52/shield.svg
     :target: https://pyup.io/repos/github/SebastianRoll/thingy52/
     :alt: Updates


Interface to Thingy:52


* Free software: MIT license
* Documentation: https://thingy52.readthedocs.io.


Install
-------

Python 3:
.. highlight:: bash

    $ sudo apt-get install libglib2.0-dev
    $ pip install thingy52

If you find bluepy-helper isn't being built, please try:

.. highlight:: bash

    $ pip install --no-binary :all: thingy52

Features
--------

* TODO

More information
----------------

* https://nordicsemiconductor.github.io/Nordic-Thingy52-FW/documentation/firmware_architecture.html
* https://infocenter.nordicsemi.com/index.jsp?topic=%2Fcom.nordic.infocenter.rds%2Fdita%2Frds%2Fdesigns%2Fthingy%2Fhw_description%2Fhw_descr.html&cp=9_0_6

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

